"use strict";
/*
 * Copyright (C) 2018 Shuma Yoshioka
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
Object.defineProperty(exports, "__esModule", { value: true });
var interfaces_1 = require("../interfaces");
var NodeCookie = require("cookie");
var NodeHttpHandler = /** @class */ (function () {
    function NodeHttpHandler(req, res) {
        this.req = req;
        this.res = res;
    }
    NodeHttpHandler.prototype.get = function (key) {
        if (typeof this.req.headers['cookie'] === 'string') {
            var cookies = NodeCookie.parse(this.req.headers['cookie']);
            if (cookies.hasOwnProperty(key)) {
                return cookies[key];
            }
        }
        return undefined;
    };
    NodeHttpHandler.prototype.set = function (key, value, options) {
        var filled = __assign({}, interfaces_1.UniversalCookies.Options.DEFAULT, options);
        var rawHeader = this.res.getHeader('Set-Cookie');
        var headers;
        switch (typeof rawHeader) {
            case 'number':
                headers = [rawHeader.toString()];
                break;
            case 'string':
                headers = [rawHeader];
                break;
            default:
                headers = rawHeader ? rawHeader : [];
        }
        this.res.setHeader('Set-Cookie', new Array().concat(headers).concat([
            NodeCookie.serialize(key, value, {
                expires: filled.expires,
                path: filled.path,
                domain: filled.domain,
                secure: filled.secure,
            })
        ]));
    };
    return NodeHttpHandler;
}());
exports.NodeHttpHandler = NodeHttpHandler;
